Numerator and denominator ACS codes of the five built-in rates
Source:R/derive-rates.R
cacs_acs_default_rates.RdThe numerator and denominator codes of each of the five rates that
cacs_derive_rates() and cacs_run() compute. The codes are American
Community Survey (ACS) variable codes. The list is the default, and the
only accepted value, of the rates argument of both functions.
Format
A named list of five character vectors, one for each rate. Each
vector has the elements num and den, the ACS codes of the numerator
and the denominator.
Details
The five rates are:
poverty_ratePeople whose income in the past 12 months was below the poverty level (
B17001_002) divided by people for whom poverty status is determined (B17001_001).snap_rateHouseholds that received Food Stamps or the Supplemental Nutrition Assistance Program (SNAP) in the past 12 months (
B22003_002) divided by all households (B22003_001).ssi_rateHouseholds with Supplemental Security Income (SSI) in the past 12 months (
B19056_002) divided by all households (B19056_001).unemp_rateUnemployed people in the civilian labor force (
B23025_005) divided by the civilian labor force (B23025_003), among people 16 years and over.labor_force_participationPeople in the labor force, including the armed forces (
B23025_002), divided by people 16 years and over (B23025_001).
See also
cacs_derive_rates() computes the rates and their margins of
error, and vignette("theory-derived-rates", package = "catchmentACS")
(https://joonho112.github.io/catchmentACS/articles/theory-derived-rates.html)
explains the calculations.
Other rates and margins of error:
cacs_moe_to_se(),
cacs_se_to_moe()
Examples
names(cacs_acs_default_rates)
#> [1] "poverty_rate" "snap_rate"
#> [3] "ssi_rate" "unemp_rate"
#> [5] "labor_force_participation"
# The codes of the numerator and the denominator of the poverty rate
cacs_acs_default_rates$poverty_rate
#> num den
#> "B17001_002" "B17001_001"