Divides a margin of error (MOE) by the normal quantile \(z\) for the
level, giving the standard error (SE):
\(\mathrm{SE} = \mathrm{MOE} / z\). A margin of error is
the half-width of a confidence interval. When level is 0.90, the
level of published American Community Survey (ACS) margins of error, the
function uses \(z = 1.645\), the value the Census Bureau uses. At other
levels it uses qnorm(1 - (1 - level) / 2). The function is the inverse
of cacs_se_to_moe() at the same level.
Details
ACS 1-year margins of error for 2005 and earlier were published with
\(z = 1.65\); dividing them by 1.65 gives the standard error. The
values of moe are not checked. The negative codes that the Census
Bureau's data API puts in place of some margins of error, such as
-555555555, are divided like any other number and give negative
standard errors. cacs_acs_prefetch() returns these codes as NA.
References
U.S. Census Bureau (2020). Understanding and Using American Community Survey Data: What All Data Users Need to Know. Chapter 7, Understanding Error and Determining Statistical Significance.
See also
cacs_propagate_moe() computes margins of error for drive-time
area estimates.
Other rates and margins of error:
cacs_acs_default_rates,
cacs_se_to_moe()
Examples
cacs_moe_to_se(c(8.225, 16.45, NA), level = 0.90)
#> [1] 5 10 NA